@@ -1,14 +1,14 @@
 import warnings
 warnings.filterwarnings("ignore", category=FutureWarning)
 import numpy as np
-from src.BiT import taxonomy as taxo
-from src.BiT import biodiversity as bio
-from src.Channel_Split import concat_features_extract_measures as extract
-from src.Channel_Split import concat_features_extract_measures_normalized as normalized_extract
-from src.Channel_Split import rgb_split_case_1 as split1
-from src.Channel_Split import rgb_split_case_2 as split2
-from src.Channel_Split import rgb_split_case_3 as split3
-from src.Channel_Split import rgb_split_case_4 as split4
+from BiT import taxonomy as taxo
+from BiT import biodiversity as bio
+from Channel_Split import concat_features_extract_measures as extract
+from Channel_Split import concat_features_extract_measures_normalized as normalized_extract
+from Channel_Split import rgb_split_case_1 as split1
+from Channel_Split import rgb_split_case_2 as split2
+from Channel_Split import rgb_split_case_3 as split3
+from Channel_Split import rgb_split_case_4 as split4
 
 '''Functions to evaluate each possibility of parameters combination '''
 ''' 
